---
title: Howto Btrfs
categories: filesystem system
...

* Documentation : <https://btrfs.wiki.kernel.org/index.php/Main_Page#Documentation>
* Wikipédia Btrfs : <https://fr.wikipedia.org/wiki/Btrfs>
* BTRFS sous Debian : <https://wiki.debian.org/Btrfs>

[Btrfs](https://btrfs.wiki.kernel.org/index.php/Main_Page) (B-tree file system, se prononce « Butter-FS ») est un système de fichiers basé sur le principe du [Copy-On-Write](https://fr.wikipedia.org/wiki/Copy-on-write) visant à mettre en œuvre des fonctionnalités avancées comme la tolérance aux pannes, la réparation et la facilité d'administration. Sous licence GNU GPL il est développé conjointement par Oracle, Red Hat, Fujitsu, Intel, SUSE, STRATO AG (en)…
En 2012, un effort intense de développement et de test est fourni par la communauté afin de faire de Btrfs le successeur de ext3/ext4, systèmes de fichiers habituels des distributions Linux. 

Btrfs offre notamment les fonctionnalités suivantes absentes d'autres systèmes de fichiers :

- Instantanés (snapshots)
- Somme de contrôle

Nous utilisons pour l'instant Btrfs uniquement sur des systèmes de stockages secondaires, comme les serveurs de sauvegardes, où l'on profite de la performance des snapshots.


## Installation

~~~
# apt install btrfs-progs
~~~

## Utilisation de base

Lister les volumes existants :

~~~
# btrfs filesystem show
~~~

Note : `filesystem` peut être abrégé `fi`.

Afficher l'espace occupé :

~~~
# btrfs filesystem df <VOLUME_PATH>
~~~

Formater une partition :

~~~
# mkfs.btrfs /dev/sda9
~~~

Montage persistant (ajouter l'option `ssd` pour les disques SSD) :

~~~
# echo "/dev/sda9 /backup btrfs defaults 0 0" >> /etc/fstab
# mount /backup
~~~

Augmenter la taille d'une partition montée :

~~~
# btrfs filesystem resize +42g /backup
~~~

Réduire la taille d'une partition montée :

~~~
# btrfs filesystem resize -42g /backup
~~~

### subvolumes et snapshots

Un subvolume est comparable à un simple répertoire (il peut contenir des fichiers et d'autres répertoires). Lorsque que l'on utilise Btrfs, il existe au moins un subvolume, le subvolume racine.

~~~
# btrfs subvolume create /backup/aaa
# btrfs subvolume create /backup/bbb
~~~

Liste des subvolumes disponibles :

~~~
# btrfs subvolume list /backup/
~~~

Un snapshot est un intantané figé de toutes les données contenues dans un subvolume. Si par exemple vous disposez deux fichiers ("foo" et "bar") dans un subvolume, un snapshot avant la suppression d'un de ces deux vous permettra de le récupérer dans ce snapshot.

> *Note* : Un snapshot n'est pas une sauvegarde, il s'appuie sur le mécanisme de copy-on-write de Btrfs. Il partage donc les mêmes blocs de données. Ainsi, si les données sont endommagées, elles le seront aussi bien sur le snapshot que sur le subvolume. Cette fonctionnalité est utile pour conserver une ou plusieurs copies locales qui peuvent enuite être utilisées pour effectuer un rollback ou une sauvegarde à partir de l'état figé d'un subvolume.

Créer un snapshot :

~~~
# btrfs subvolume snapshot /backup/aaa /backup/bbb/snapshot1
~~~

Supprimer un subvolume (et snapshot) :

~~~
# btrfs subvolume delete /bbb/bbb/snapshot1
~~~

Lister les propriétés d'un subvolume :

~~~
# btrfs property list -ts /path/to/subvolume
~~~

Passer un subvolume en RW :

~~~
# btrfs property set -ts /path/to/subvolume ro false
~~~

Passer un subvolume en RO :

~~~
# btrfs property set -ts /path/to/subvolume ro true
~~~

#### Manipulations d'un subvolume

Pour déplacer un subvolume, il faut créer un snapshot en read-only du subvolume que l'on souhaite déplacer/renommer puis supprimer l'original. 

~~~
# btrfs sub snap -r /path/to/subvolume /path/to/snapshot
# btrfs subvolume delete /path/to/subvolume
~~~

On passera ensuite le volume en RO/RW :

~~~
# btrfs property set -ts /path/to/snapshot ro false
~~~

### Envoyer un subvolume

Pour transférer un subvolume vers un autre serveur, il faut créer un snapshot en RO du subvolume en question.

~~~
# btrfs sub snap -r /path/to/subvolume /path/to/snapshot-RO
~~~

On peut ensuite envoyer le volume via SSH :

~~~
# btrfs send /path/to/snapshot-RO | ssh root@192.0.2.1 "btrfs receive /path/to/remote-snapshot"
~~~

### Compression

On peut monter avec l'option `compress=zlib` ou `compress=lzo` pour activer une compression à la volée des fichiers.
Si le volume avant n'avait pas l'option `compress` on pourra tout recompresser avec `btrfs filesystem defragment -czlib` ou `-clzo`.

## Maintenance

Vérifier l'intégrité d'un subvolume avec l'opération **scrub** qui lance une lecture de l'ensemble des données et métadonnées du système de fichiers et utilise les sommes de contrôle pour identifier et réparer les données corrompues éventuelles :

~~~
# btrfs scrub start /backup/
# btrfs scrub status /backup/
~~~

Vérification plus poussée sur une partition non montée :

~~~
# btrfs check -p /dev/sda9
~~~

Voir si la partition a présenté des erreurs :

~~~
# btrfs dev stats /backup
~~~

